@@ -1,5 +1,5 @@
-use crate::log::{println_label, OutputLabel};
 use git2::{Branch, BranchType, Repository, Status};
+use label_logger::OutputLabel;
 
 /// Check if repository has unsaved files in working or dirty directory
 pub fn is_repo_dirty(repo: &Repository) -> bool {
@@ -26,10 +26,7 @@ pub fn find_ahead_branches_in_repo(repo: &Repository) -> Vec<Branch> {
 	let local_branches = match repo.branches(Some(BranchType::Local)) {
 		Ok(branches) => branches.map(|b| b.unwrap().0).collect::<Vec<Branch>>(),
 		Err(err) => {
-			println_label(
-				OutputLabel::Error,
-				format!("in {}: {}", repo.path().display(), err.message()),
-			);
+			eprintln!("in {}: {}", repo.path().display(), err.message());
 
 			return vec![];
 		}
@@ -44,13 +41,10 @@ pub fn find_ahead_branches_in_repo(repo: &Repository) -> Vec<Branch> {
 				match branch.get().peel_to_commit() {
 					Ok(commit) => commit,
 					Err(err) => {
-						println_label(
-							OutputLabel::Error,
-							format!(
-								"in {}: could not get last commit on local branch: {}",
-								repo.path().display(),
-								err.message()
-							),
+						eprintln!(
+							"in {}: could not get last commit on local branch: {}",
+							repo.path().display(),
+							err.message()
 						);
 
 						return vec![];
@@ -69,13 +63,11 @@ pub fn find_ahead_branches_in_repo(repo: &Repository) -> Vec<Branch> {
 				ahead_branches.push(branch)
 			}
 		} else {
-			println_label(
+			println!(
 				OutputLabel::Info("Info"),
-				format!(
-					"No upstream branch for {} in {}",
-					branch.name().unwrap().unwrap_or("<no name found>"),
-					repo.path().parent().unwrap().to_str().unwrap()
-				),
+				"No upstream branch for {} in {}",
+				branch.name().unwrap().unwrap_or("<no name found>"),
+				repo.path().parent().unwrap().to_str().unwrap()
 			);
 		}
 	}
